# Security Policy

## Supported Versions

|     Version      |  Supported?   |
| :--------------: | :-----------: |
| `main` at `HEAD` |  :thumbsup:   |
|  Anything else   | :see_no_evil: |

## Reporting a Vulnerability

If you think you might have found a security vulnerability, [**please report it
privately**][report-link] so that it can be fixed ASAP. 💜

[report-link]:
  https://docs.github.com/en/code-security/security-advisories/guidance-on-reporting-and-writing/privately-reporting-a-security-vulnerability#privately-reporting-a-security-vulnerability
